<?xml version="1.0" encoding="UTF-8" ?>

<!--
  ======================================================================
  このスタイルシートは、「気象庁防災情報XMLフォーマット」に対して活用事例を示すサンプルであり、資料として参照することを目的とする。
  よって、本スタイルシートを直接利用した場合に発生する問題に対して、気象庁は責任を負わない。
  Copyright (c) 気象庁 2010 All rights reserved.

  【本スタイルシートの説明】
  予報課指定河川洪水予報用

  【更新履歴】
  2010年8月 6日　Ver.1.0 　初期版
  ======================================================================
-->


<!-- 名前空間の指定 気象庁使用の名前空間 -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/" exclude-result-prefixes="jmx"
 xmlns:h="http://xml.kishou.go.jp/jmaxml1/informationBasis1/"
 xmlns:b="http://xml.kishou.go.jp/jmaxml1/body/meteorology1/"
 xmlns:e="http://xml.kishou.go.jp/jmaxml1/elementBasis1/"
 >

<!-- 出力文字コード -->
<xsl:output method="html" indent="no" encoding="Shift-JIS"/>

<!-- メイン -->
<xsl:template match="/">
	<xsl:apply-templates select="jmx:Report" />
	
	<xsl:apply-templates select="jmx:Report/h:Head/h:Headline" />
	
	<xsl:apply-templates select="jmx:Report/b:Body" />
	
</xsl:template>

<xsl:template match="b:Body">

	<xsl:apply-templates select="b:Warning" />
	<xsl:apply-templates select="b:MeteorologicalInfos" />
	<xsl:apply-templates select="b:OfficeInfo" />
	<xsl:apply-templates select="b:AdditionalInfo" />

</xsl:template>

<xsl:template match="b:AdditionalInfo">

	<br/>

	<xsl:if test="b:FloodForecastAddition">
		<font color="navy" size="+1">
			<xsl:text>参考資料</xsl:text>
		</font>
	</xsl:if>
	<table border="1">
	<tr>
		<td rowspan="2">観測署名</td>

	<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
		<td><xsl:value-of select="b:Area/b:Name"/></td>
	</xsl:for-each>
	
	</tr><tr>
	
	<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
		<td><xsl:value-of select="b:Area/b:Location"/></td>
	</xsl:for-each>

	</tr>

	<xsl:if test="b:FloodForecastAddition/b:HydrometricStationPart/b:Criteria/e:WaterLevel or b:FloodForecastAddition/b:HydrometricStationPart/b:Criteria/e:Discharge">
		<tr><td>はん濫危険水位</td>
		<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
			<td>
				<xsl:if test="b:Criteria/e:WaterLevel[@type='はん濫危険水位' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:WaterLevel[@type='はん濫危険水位']"/>
					<xsl:value-of select="b:Criteria/e:WaterLevel/@unit"/>
				</xsl:if>
				<xsl:if test="b:Criteria/e:Discharge[@type='はん濫危険流量' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:Discharge[@type='はん濫危険流量']"/>
					<xsl:value-of select="b:Criteria/e:Discharge/@unit"/>
				</xsl:if>
			</td>
		</xsl:for-each>
		</tr>

		<tr><td>避難判断水位</td>
		<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
			<td>
				<xsl:if test="b:Criteria/e:WaterLevel[@type='避難判断水位' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:WaterLevel[@type='避難判断水位']"/>
					<xsl:value-of select="b:Criteria/e:WaterLevel/@unit"/>
				</xsl:if>
				<xsl:if test="b:Criteria/e:Discharge[@type='避難判断流量' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:Discharge[@type='避難判断流量']"/>
					<xsl:value-of select="b:Criteria/e:Discharge/@unit"/>
				</xsl:if>
			</td>
		</xsl:for-each>
		</tr>

		<tr><td>はん濫注意水位</td>
		<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
			<td>
				<xsl:if test="b:Criteria/e:WaterLevel[@type='はん濫注意水位' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:WaterLevel[@type='はん濫注意水位']"/>
					<xsl:value-of select="b:Criteria/e:WaterLevel/@unit"/>
				</xsl:if>
				<xsl:if test="b:Criteria/e:Discharge[@type='はん濫注意流量' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:Discharge[@type='はん濫注意流量']"/>
					<xsl:value-of select="b:Criteria/e:Discharge/@unit"/>
				</xsl:if>
			</td>
		</xsl:for-each>
		</tr>

		<tr><td>水防団待機水位</td>
		<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
			<td>
				<xsl:if test="b:Criteria/e:WaterLevel[@type='水防団待機水位' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:WaterLevel[@type='水防団待機水位']"/>
					<xsl:value-of select="b:Criteria/e:WaterLevel/@unit"/>
				</xsl:if>
				<xsl:if test="b:Criteria/e:Discharge[@type='水防団待機流量' and @condition='有効']">
					<xsl:value-of select="b:Criteria/e:Discharge[@type='水防団待機流量']"/>
					<xsl:value-of select="b:Criteria/e:Discharge/@unit"/>
				</xsl:if>
			</td>
		</xsl:for-each>
		</tr>

	</xsl:if>


	<tr><td>受け持ち区間</td>
	<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
	<td>
		<table>
			<xsl:for-each select="b:ChargeSection">
			<tr><td>
				<xsl:value-of select="."/>
			</td></tr>
			</xsl:for-each>
		</table>
	</td>
	</xsl:for-each>
	</tr>

	<tr><td>氾濫が発生した場合の想定浸水区域</td>
	<xsl:for-each select="b:FloodForecastAddition/b:HydrometricStationPart">
	<td>
		<xsl:value-of select="b:Area/b:SubCityList"/>
	</td>
	</xsl:for-each>
	</tr>
	</table>

</xsl:template>

<xsl:template match="b:OfficeInfo">

	<br/>
	<font color="navy" size="+1">
		<xsl:text>問い合わせ先</xsl:text>
	</font>

	<table border="1">
	<xsl:for-each select="b:Office">
		<tr>
			<td rowspan="2"><xsl:value-of select="@type"/></td>
			<td><xsl:value-of select="b:Name" /><xsl:text>　ホームページ：</xsl:text><xsl:value-of select="b:URI" /></td>
		</tr>
		<tr><td><xsl:value-of select="b:ContactInfo" /></td></tr>
	</xsl:for-each>
	</table>


</xsl:template>


<xsl:template match="b:MeteorologicalInfos">

	<xsl:if test="@type='はん濫水の予報'">
		<br/>
		<font color="navy" size="+1">
			<xsl:value-of select="@type" />
		</font>
		<br/>
		<xsl:value-of select="b:MeteorologicalInfo/b:Item/b:Kind/b:Property/b:Text" />
		<br/>
		
		<table border="1">
		<tr><td>浸水想定箇所</td><td>想定到達時刻＊</td><td>想定最大浸水深</td><td>浸水最深時刻＊</td></tr>
		
		<xsl:for-each select="b:MeteorologicalInfo/b:Item/b:Kind/b:Property/b:FloodAssumptionTable/b:FloodAssumptionPart">
		<tr>
			<td><xsl:value-of select="b:FloodAssumptionArea"/></td>
			<td><xsl:value-of select="b:AttainmentTime/@description"/>
				<xsl:text>（</xsl:text>
				<xsl:call-template name="hiduke00">
					<xsl:with-param name="value" select="b:AttainmentTime" />
				</xsl:call-template>
				<xsl:value-of select="b:AttainmentTime/@dubious"/>
				<xsl:text>）</xsl:text>
			</td>
			
			<td>
				<xsl:if test="e:FloodDepth[@bound='以上']">
					<xsl:value-of select="e:FloodDepth[@bound='以上']"/><xsl:text>以上</xsl:text>
				</xsl:if>
				<xsl:if test="e:FloodDepth[@bound='未満']">
					<xsl:value-of select="e:FloodDepth[@bound='未満']"/><xsl:text>未満</xsl:text>
				</xsl:if>
			</td>
			
			<td><xsl:value-of select="b:AttainmentDeepestTime/@description"/>
				<xsl:text>（</xsl:text>
				<xsl:call-template name="hiduke00">
					<xsl:with-param name="value" select="b:AttainmentDeepestTime" />
				</xsl:call-template>
				<xsl:value-of select="b:AttainmentDeepestTime/@dubious"/>
				<xsl:text>）</xsl:text>
			</td>


		</tr>
		</xsl:for-each>
		</table>
		<xsl:text>＊はん濫発生からの時間を示しています。</xsl:text>
		<br/>
	</xsl:if>


	<xsl:if test="@type='雨量情報'">
		<br/>
		<font color="navy" size="+1">
			<xsl:value-of select="@type" />
		</font>
		<br/>

		<xsl:value-of select="b:MeteorologicalInfo/b:Item/b:Kind/b:Property/b:Text" />

		<table border="1">
		<tr>
		<td>
			<xsl:if test="b:TimeSeriesInfo/b:Item/b:Area/b:Name">
			<xsl:text>流域</xsl:text>
			</xsl:if>
		</td>
	
		<xsl:for-each select="b:TimeSeriesInfo/b:TimeDefines/b:TimeDefine">
			<td>
			<xsl:value-of select="b:Name"/>
			</td>
		</xsl:for-each>
		</tr>
	
		<tr>
		<td>
			<xsl:if test="b:TimeSeriesInfo/b:Item/b:Area/b:Name">
			<xsl:value-of select="b:TimeSeriesInfo/b:Item/b:Area/b:Name"/>
			</xsl:if>
		</td>
		<xsl:for-each select="b:TimeSeriesInfo/b:Item/b:Kind/b:Property/b:PrecipitationPart/e:Precipitation">
			<td><xsl:value-of select="@type"/><xsl:value-of select="." /><xsl:value-of select="@unit"/></td>
		</xsl:for-each>

		</tr>
		</table>

	</xsl:if>

	<xsl:if test="@type='水位・流量情報'">
		<br/>
		<font color="navy" size="+1">
			<xsl:value-of select="@type" />
		</font>
		<br/>

		<xsl:value-of select="b:MeteorologicalInfo/b:Item/b:Kind/b:Property/b:Text" />

		<table border="1">
		<tr>
		<td>
			<xsl:if test="b:TimeSeriesInfo/b:Item/b:Station/b:Name">
			<xsl:text>観測所</xsl:text>
			</xsl:if>
		</td>

		<xsl:for-each select="b:TimeSeriesInfo/b:TimeDefines/b:TimeDefine">
			<td colspan="2">
			<xsl:value-of select="b:Name"/>
			</td>
		</xsl:for-each>

		</tr>

		<xsl:for-each select="b:TimeSeriesInfo/b:Item">

			<tr>
			<td>
				<xsl:value-of select="b:Station/b:Name"/>
			</td>

			<xsl:for-each select="b:Kind/b:Property/b:WaterLevelPart/e:WaterLevel">
				<td>
					<xsl:if test="@type='水位' or @type='流量'">
						<xsl:if test="@condition='未計算'">
							<xsl:text>未計算</xsl:text>
						</xsl:if>
						<xsl:if test="@condition!='未計算'">
							<xsl:value-of select="@type"/>
							<xsl:value-of select="."/>
							<xsl:value-of select="@unit"/>
							<xsl:if test="@condition!='正常'">
								<xsl:text>（</xsl:text><xsl:value-of select="@condition"/><xsl:text>）</xsl:text>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<xsl:if test="@type='レベル'">
						<xsl:value-of select="@type"/>
						<xsl:value-of select="."/>
					</xsl:if>
				</td>
			</xsl:for-each>

			<xsl:for-each select="b:Kind/b:Property/b:DischargePart/e:Discharge">
				<td>
					<xsl:if test="@type='水位' or @type='流量'">
						<xsl:if test="@condition='未計算'">
							<xsl:text>未計算</xsl:text>
						</xsl:if>
						<xsl:if test="@condition!='未計算'">
							<xsl:value-of select="@type"/>
							<xsl:value-of select="."/>
							<xsl:value-of select="@unit"/>
							<xsl:if test="@condition!='正常'">
								<xsl:text>（</xsl:text><xsl:value-of select="@condition"/><xsl:text>）</xsl:text>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<xsl:if test="@type='レベル'">
						<xsl:value-of select="@type"/>
						<xsl:value-of select="."/>
					</xsl:if>
				</td>
			</xsl:for-each>
			</tr>

		</xsl:for-each>
		</table>
	</xsl:if>

</xsl:template>


<xsl:template match="b:Warning">

	<font color="navy" size="+1">
	<xsl:text>＜</xsl:text>
	<xsl:value-of select="@type" />
	<xsl:text>＞</xsl:text>
	</font>

	<br/>

	<xsl:for-each select="b:Item">

		<xsl:value-of select="b:Kind/b:Property/b:Type"/><br/>
		<xsl:value-of select="b:Kind/b:Property/b:Text"/><br/>
		
		<xsl:if test="b:Kind/b:Property/b:Type='浸水想定地区'">

			<table border="1">

			<xsl:for-each select="b:Areas/b:Area">
			<tr>
				<td>
				<xsl:value-of select="b:Name"/>
				<!-- <xsl:value-of select="b:Code"/> -->
				</td>
				<td>
				<xsl:value-of select="b:Prefecture"/>
				</td>
				<td>
				<xsl:value-of select="b:City"/>
				</td>
				<td>
				<xsl:value-of select="b:SubCityList"/>
				</td>
			</tr>
			</xsl:for-each>
			</table>
		</xsl:if>

		<xsl:if test="b:Kind/b:Property/b:Type='浸水想定地区（はん濫発生情報）'">

			<table border="1">

			<xsl:for-each select="b:Areas/b:Area">
			<tr>
				<td>
				<xsl:value-of select="b:Prefecture"/>
				</td>
				<td>
				<xsl:value-of select="b:City"/>
				</td>
				<td>
				<xsl:value-of select="b:SubCityList"/>
				</td>
			</tr>
			</xsl:for-each>
			</table>
		</xsl:if>

	<br/>

	</xsl:for-each>

</xsl:template>


<xsl:template match="h:Headline">
	<b>
	<xsl:call-template name="InsertBlank">
		<xsl:with-param name="value" select="h:Text"/>
	</xsl:call-template>
	</b>
	<xsl:call-template name="newLine"/>
	<xsl:call-template name="newLine"/>

</xsl:template>


<xsl:template match="jmx:Report">

	<h2>
		<xsl:value-of select="h:Head/h:Title" />
	</h2>
	
	<xsl:for-each select="h:Head/h:Headline/h:Information">
		<xsl:if test="@type='指定河川洪水予報（予報区域）'">
			<xsl:value-of select="h:Item/h:Kind/h:Condition" />
			<br />
			<xsl:value-of select="h:Item/h:Areas/h:Area/h:Name" /><xsl:text>洪水予報</xsl:text>
		</xsl:if>
	</xsl:for-each>
	<xsl:text>　第</xsl:text><xsl:value-of select="h:Head/h:Serial" /><xsl:text>号</xsl:text>
	<br />

	<xsl:call-template name="hiduke" />
	<br />
	<xsl:value-of select="jmx:Control/jmx:PublishingOffice"/><xsl:text>　発表</xsl:text>

	<xsl:if test="contains(h:Head/h:InfoType,'訂正')">
		<br />
		<xsl:text>（訂正）</xsl:text>
	</xsl:if>

	<xsl:call-template name="newLine"/>
	<xsl:call-template name="newLine"/>

</xsl:template>


<xsl:template name="hiduke">
	<xsl:variable name="reportTime" select="h:Head/h:ReportDateTime" />

	<xsl:text>平成</xsl:text>
	<xsl:value-of select="translate(substring($reportTime,1,4) - 1988,'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>年</xsl:text>
	<xsl:value-of select="translate(substring($reportTime,6,1),'0123456789', '　１２３４５６７８９')"/>
	<xsl:value-of select="translate(substring($reportTime,7,1),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>月</xsl:text>
	<xsl:value-of select="translate(substring($reportTime,9,1),'0123456789', '　１２３４５６７８９')"/>
	<xsl:value-of select="translate(substring($reportTime,10,1),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>日</xsl:text>
	<xsl:value-of select="translate(substring($reportTime,12,2),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>時</xsl:text>
	<xsl:value-of select="translate(substring($reportTime,15,2),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>分</xsl:text>
	<xsl:text>　</xsl:text>
</xsl:template>


<xsl:template name="InsertBlank">
	<xsl:param name="value"/>
	<xsl:choose>
		<xsl:when test="contains($value, '&#xA;')">
			<xsl:value-of select="concat('　', substring-before($value, '&#xA;'))"/>
			<xsl:call-template name="newLine"/>
			<xsl:call-template name="InsertBlank">
				<xsl:with-param name="value" select="substring-after($value, '&#xA;')"/>
			</xsl:call-template>
		</xsl:when>

		<xsl:otherwise>
			<xsl:value-of select="concat('　', $value)"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<xsl:template name="newLine"><BR/></xsl:template>

<xsl:template name="hiduke00">
	<xsl:param name="value" />
	<xsl:value-of select="translate(substring($value,6,1),'0123456789', '　１２３４５６７８９')"/>
	<xsl:value-of select="translate(substring($value,7,1),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>月</xsl:text>
	<xsl:value-of select="translate(substring($value,9,1),'0123456789', '　１２３４５６７８９')"/>
	<xsl:value-of select="translate(substring($value,10,1),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>日</xsl:text>
	<xsl:value-of select="translate(substring($value,12,2),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>時</xsl:text>
	<xsl:value-of select="translate(substring($value,15,2),'0123456789', '０１２３４５６７８９')"/>
	<xsl:text>分</xsl:text>
</xsl:template>
</xsl:stylesheet>
